require 'json'

module Sprintly
  class Item
    WHITELISTED_ATTRIBUTES = [
      "status", "description", "tags", "title",
      "progress", "number", "created_by",
      "score", "sort", "type", "assigned_to"
    ].freeze

    def self.for_product(product_id)
      response = Sprintly::Connection.get("products/#{product_id}/items.json")
      raw_items = JSON.parse(response.body)
      raw_items.map { |raw_item| new(raw_item) }
    end

    def self.all_for_product(product_id)
      response = Sprintly::Connection.get("products/#{product_id}/items.json?status=someday,backlog,in-progress,completed,accepted")
      raw_items = JSON.parse(response.body)
      raw_items.map { |raw_item| new(raw_item) }
    end

    def initialize(raw_item)
      WHITELISTED_ATTRIBUTES.each do |attr|
        if raw_item.has_key?(attr)
          instance_variable_set("@#{attr}", raw_item[attr])
          singleton_class.class_eval do
            attr_reader "#{attr}"
          end
        end
      end
    end
  end
end
